@@ -71,11 +71,11 @@ PARSE-SPEC is a function of no argument advancing the point and returning
   either a fileinfo or t (if the matched text should be ignored) or
   nil if it didn't match anything.
 DONT-CHANGE-DISC just indicates whether the command was changing the disc
-  or not (useful to tell the difference btween `cvs-examine' and `cvs-update'
-  ouytput.
+  or not (useful to tell the difference between `cvs-examine' and `cvs-update'
+  output.
 The path names should be interpreted as relative to SUBDIR (defaults
   to the `default-directory').
-Return a list of collected entries, or t if an error occured."
+Return a list of collected entries, or t if an error occurred."
   (goto-char (point-min))
   (let ((fileinfos ())
 	(cvs-current-dir "")
@@ -391,6 +391,8 @@ The remaining KEYS are passed directly to `cvs-create-fileinfo'."
 			   "\\) already contains the differences between .*$")
 		   (path 1) (type '(UP-TO-DATE . MERGED)))
 	t)
+       ;; FIXME: PATH might not be set yet.  Sometimes the only path
+       ;; information is in `RCS file: ...' (yuck!!).
        (cvs-parsed-fileinfo (if dont-change-disc 'NEED-MERGE
 			      (or type '(MODIFIED . MERGED))) path nil
 			    :merge (cons base-rev head-rev))))))
